@@ -8,7 +8,7 @@ class ScreenshotResult(ResultBase):
     def __init__(self, result, successMessage, failMessage):
         ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)
 
-        self.filePath = result["generatedFilename"]
+        self.filePath = result["filePath"]
 
         if self.success is True:
             return
